import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format,
} from 'd3';

const sectionColors = [
  'green',
  'brown',
  'Pink',
  'skyblue',
  'Grey',
  'violet',
  'orange',
  'wheat',
  'lightgreen',
  'aqua',
]; //Different colors for representation
//dataset Url made raw from github
const csvUrl =
  'https://gist.githubusercontent.com/mosesvemana/52a9ad6223560f8c8d631ea3e41c2df3/raw/861e14caef04a6d5ed6f83e1c942e38d6e6426df/Future50.csv';
//fetching data from dataset
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const xAxisTickFormat = (number) =>
  format('.4~g')(number);

const render = (data, total) => {
  const pieData = pie().value((d) => d.Sales)(
    data
  );
  const colors = scaleOrdinal()
    .domain(data)
    .range(sectionColors);

  const arcGenerator = d3
    .arc()
    .innerRadius(0)
    .outerRadius(250);

  //arc
  const segments = arc()
    .innerRadius(0)
    .outerRadius(175)
    .padAngle(0)
    .padRadius(0);

  const sections = svg
    .append('g')
    .attr('transform', `translate(250,250)`)
    .selectAll('path')
    .data(pieData);

  sections
    .enter()
    .append('path')
    .attr('d', segments)
    .attr('fill', (d) => colors(d.data.Sales));
  //section label
  sections
    .enter()
    .append('text')
    .text(
      (d) =>
        xAxisTickFormat(d.data.Sales / 1000) + 'K'
    )
    .attr('transform', function (d) {
      return (
        'translate(' +
        arcGenerator.centroid(d) +
        ')'
      );
    })
    .style('text-anchor', 'middle')
    .style('fill', 'black')
    .style('font-size', 15);
  //legends
  const legends = svg
    .append('g')
    .attr('transform', 'translate(500,100)')
    .selectAll('.legends')
    .data(pieData);

  const legend = legends
    .enter()
    .append('g')
    .classed('.legends', true)
    .attr('transform', (d, i) => {
      return `translate(0,${(i + 1) * 30})`;
    });

  legend
    .append('rect')
    .attr('width', 20)
    .attr('height', 20)
    .attr('fill', (d) => colors(d.data.Sales));
  legend
    .append('text')
    .attr('x', 25)
    .attr('y', 15)
    .attr('class', 'legend_text')
    .text((d) => d.data.Restaurant);
  legend
    .append('text')
    .attr('x', 250)
    .attr('y', 15)
    .attr('class', 'legend_value')
    .text(
      (d) =>
        xAxisTickFormat(d.data.Sales / 1000) + 'K'
    );
};

const run = async () => {
  let data = await fetchData();
  let total = 0;
  data.forEach((d) => {
    d.Sales = +d.Sales;
    total += d.Sales;
  });
  render(data, total);
};
run();
